package com.ruoyi.cs.service;

import java.util.List;
import com.ruoyi.cs.domain.CsOrderClass;

/**
 * 工单类型Service接口
 *
 * @author ruoyi
 * @date 2024-04-23
 */
public interface ICsOrderClassService
{
    /**
     * 查询工单类型
     *
     * @param orderClassId 工单类型主键
     * @return 工单类型
     */
    public CsOrderClass selectCsOrderClassByOrderClassId(String orderClassId);

    /**
     * 查询工单类型列表
     *
     * @param csOrderClass 工单类型
     * @return 工单类型集合
     */
    public List<CsOrderClass> selectCsOrderClassList(CsOrderClass csOrderClass);

    /**
     * 新增工单类型
     *
     * @param csOrderClass 工单类型
     * @return 结果
     */
    public int insertCsOrderClass(CsOrderClass csOrderClass);

    /**
     * 修改工单类型
     *
     * @param csOrderClass 工单类型
     * @return 结果
     */
    public int updateCsOrderClass(CsOrderClass csOrderClass);

    /**
     * 批量删除工单类型
     *
     * @param orderClassIds 需要删除的工单类型主键集合
     * @return 结果
     */
    public int deleteCsOrderClassByOrderClassIds(String[] orderClassIds);

    /**
     * 删除工单类型信息
     *
     * @param orderClassId 工单类型主键
     * @return 结果
     */
    public int deleteCsOrderClassByOrderClassId(String orderClassId);
}
