package com.ruoyi.controller;

import java.util.List;
import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.cs.domain.CsOrderClass;
import com.ruoyi.cs.service.ICsOrderClassService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 工单类型Controller
 *
 * @author ruoyi
 * @date 2024-04-23
 */
@RestController
@RequestMapping("/cs/csOrderClass")
public class CsOrderClassController extends BaseController
{
    @Resource
    private ICsOrderClassService csOrderClassService;

    /**
     * 查询工单类型列表
     */
    @PreAuthorize("@ss.hasPermi('cs:csOrderClass:list')")
    @GetMapping("/list")
    public TableDataInfo list(CsOrderClass csOrderClass)
    {
        startPage();
        csOrderClass.setDelFlag("0");
        List<CsOrderClass> list = csOrderClassService.selectCsOrderClassList(csOrderClass);
        return getDataTable(list);
    }

    /**
     * 导出工单类型列表
     */
    @PreAuthorize("@ss.hasPermi('cs:csOrderClass:export')")
    @Log(title = "工单类型", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CsOrderClass csOrderClass)
    {
        List<CsOrderClass> list = csOrderClassService.selectCsOrderClassList(csOrderClass);
        ExcelUtil<CsOrderClass> util = new ExcelUtil<CsOrderClass>(CsOrderClass.class);
        util.exportExcel(response, list, "工单类型数据");
    }

    /**
     * 获取工单类型详细信息
     */
    @PreAuthorize("@ss.hasPermi('cs:csOrderClass:query')")
    @GetMapping(value = "/{orderClassId}")
    public AjaxResult getInfo(@PathVariable("orderClassId") String orderClassId)
    {
        return AjaxResult.success(csOrderClassService.selectCsOrderClassByOrderClassId(orderClassId));
    }

    /**
     * 新增工单类型
     */
    @PreAuthorize("@ss.hasPermi('cs:csOrderClass:add')")
    @Log(title = "工单类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CsOrderClass csOrderClass)
    {
        return toAjax(csOrderClassService.insertCsOrderClass(csOrderClass));
    }

    /**
     * 修改工单类型
     */
    @PreAuthorize("@ss.hasPermi('cs:csOrderClass:edit')")
    @Log(title = "工单类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CsOrderClass csOrderClass)
    {
        return toAjax(csOrderClassService.updateCsOrderClass(csOrderClass));
    }

    /**
     * 删除工单类型
     */
    @PreAuthorize("@ss.hasPermi('cs:csOrderClass:remove')")
    @Log(title = "工单类型", businessType = BusinessType.DELETE)
	@DeleteMapping("/{orderClassIds}")
    public AjaxResult remove(@PathVariable String[] orderClassIds)
    {
        return toAjax(csOrderClassService.deleteCsOrderClassByOrderClassIds(orderClassIds));
    }
}
